@@ -33,7 +33,7 @@ extern "C" {
 namespace filter
 {
   
-  enum FILTER_TYPE { median=0, var=1 , min=2, max=3, sum=4, mean=5, minmax=6, dilate=7, erode=8, close=9, open=10, homog=11, sobelx=12, sobely=13, sobelxy=14, sobelyx=-14, smooth=15, density=16, majority=17, mixed=18, smoothnodata=19, threshold=20, ismin=21, ismax=22, heterog=23, order=24, stdev=25, dwt=26, dwti=27, dwt_cut=28};
+  enum FILTER_TYPE { median=0, var=1 , min=2, max=3, sum=4, mean=5, minmax=6, dilate=7, erode=8, close=9, open=10, homog=11, sobelx=12, sobely=13, sobelxy=14, sobelyx=-14, smooth=15, density=16, majority=17, mixed=18, smoothnodata=19, threshold=20, ismin=21, ismax=22, heterog=23, order=24, stdev=25, dwt=26, dwti=27, dwt_cut=28, dwt_cut_from=29};
 
 class Filter
 {
@@ -77,6 +77,7 @@ public:
   void dwtForward(std::vector<double>& data, const std::string& wavelet_type, int family);
   void dwtInverse(std::vector<double>& data, const std::string& wavelet_type, int family);
   void dwtCut(std::vector<double>& data, const std::string& wavelet_type, int family, double cut);
+  void dwtCutFrom(const ImgReaderGdal& input, ImgWriterGdal& output, const std::string& wavelet_type, int family, int band);
 
 private:
 
@@ -85,6 +86,7 @@ private:
     m_filterMap["dwt"]=filter::dwt;
     m_filterMap["dwti"]=filter::dwti;
     m_filterMap["dwt_cut"]=filter::dwt_cut;
+    m_filterMap["dwt_cut_from"]=filter::dwt_cut_from;
     m_filterMap["stdev"]=filter::stdev;
     m_filterMap["var"]=filter::var;
     m_filterMap["min"]=filter::min;
@@ -417,6 +419,7 @@ template<class T> void Filter::filter(const std::vector<T>& input, std::vector<T
   for(i=offset;i<m_taps.size()/2;++i){
     if((i-offset)%down)
       continue;
+    //todo:introduce nodata
     output[(i-offset+down-1)/down]=m_taps[m_taps.size()/2]*input[i];
     for(int t=1;t<=m_taps.size()/2;++t)
       output[(i-offset+down-1)/down]+=(m_taps[m_taps.size()/2+t]+m_taps[m_taps.size()/2-t])*input[i+t];
@@ -425,6 +428,7 @@ template<class T> void Filter::filter(const std::vector<T>& input, std::vector<T
   for(i=offset+m_taps.size()/2;i<input.size()-m_taps.size()/2;++i){
     if((i-offset)%down)
       continue;
+    //todo:introduce nodata
     T leaveOut=(*(m_taps.begin()))*input[i-m_taps.size()/2];
     T include=(m_taps.back())*input[i+m_taps.size()/2];
     output[(i-offset+down-1)/down]=0;
@@ -435,7 +439,9 @@ template<class T> void Filter::filter(const std::vector<T>& input, std::vector<T
   for(i=input.size()-m_taps.size()/2;i<input.size();++i){
     if((i-offset)%down)
       continue;
+    //todo:introduce nodata
     output[(i-offset+down-1)/down]=m_taps[m_taps.size()/2]*input[i];
+    //todo:introduce nodata
     for(int t=1;t<=m_taps.size()/2;++t)
       output[(i-offset+down-1)/down]+=(m_taps[m_taps.size()/2+t]+m_taps[m_taps.size()/2-t])*input[i-t];
   }
