@@ -24,51 +24,38 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include <algorithm>
 #include "base/Optionpk.h"
 #include "algorithms/ConfusionMatrix.h"
+#include "algorithms/CostFactory.h"
 #include "algorithms/FeatureSelector.h"
 #include "algorithms/svm.h"
 #include "imageclasses/ImgReaderOgr.h"
+#include "pkfssvm.h"
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-namespace svm{
-  enum SVM_TYPE {C_SVC=0, nu_SVC=1,one_class=2, epsilon_SVR=3, nu_SVR=4};
-  enum KERNEL_TYPE {linear=0,polynomial=1,radial=2,sigmoid=3};
-}
-
-enum SelectorValue  { NA=0, SFFS=1, SFS=2, SBS=3, BFS=4 };
-
 using namespace std;
 
 #define Malloc(type,n) (type *)malloc((n)*sizeof(type))
 
 //global parameters used in cost function getCost
-ConfusionMatrix cm;
-map<string,short> classValueMap;
-vector<std::string> nameVector;
-vector<unsigned int> nctraining;
-vector<unsigned int> nctest;
-Optionpk<std::string> svm_type_opt("svmt", "svmtype", "type of SVM (C_SVC, nu_SVC,one_class, epsilon_SVR, nu_SVR)","C_SVC");
-Optionpk<std::string> kernel_type_opt("kt", "kerneltype", "type of kernel function (linear,polynomial,radial,sigmoid) ","radial");
-Optionpk<unsigned short> kernel_degree_opt("kd", "kd", "degree in kernel function",3);
-Optionpk<float> gamma_opt("g", "gamma", "gamma in kernel function",1.0);
-Optionpk<float> coef0_opt("c0", "coef0", "coef0 in kernel function",0);
-Optionpk<float> ccost_opt("cc", "ccost", "the parameter C of C-SVC, epsilon-SVR, and nu-SVR",1000);
-Optionpk<float> nu_opt("nu", "nu", "the parameter nu of nu-SVC, one-class SVM, and nu-SVR",0.5);
-Optionpk<float> epsilon_loss_opt("eloss", "eloss", "the epsilon in loss function of epsilon-SVR",0.1);
-Optionpk<int> cache_opt("cache", "cache", "cache memory size in MB",100);
-Optionpk<float> epsilon_tol_opt("etol", "etol", "the tolerance of termination criterion",0.001);
-Optionpk<bool> shrinking_opt("shrink", "shrink", "whether to use the shrinking heuristics",false);
-Optionpk<bool> prob_est_opt("pe", "probest", "whether to train a SVC or SVR model for probability estimates",true,2);
-// Optionpk<bool> weight_opt("wi", "wi", "set the parameter C of class i to weight*C, for C-SVC",true);
-Optionpk<unsigned short> cv_opt("cv", "cv", "n-fold cross validation mode",2);
-Optionpk<string> classname_opt("c", "class", "list of class names."); 
-Optionpk<short> classvalue_opt("r", "reclass", "list of class values (use same order as in classname opt."); 
-Optionpk<short> verbose_opt("v", "verbose", "set to: 0 (results only), 1 (confusion matrix), 2 (debug)",0);
+// ConfusionMatrix cm;
+// map<string,short> classValueMap;
+// vector<std::string> nameVector;
+// vector<unsigned int> nctraining;
+// vector<unsigned int> nctest;
 
-double getCost(const vector<Vector2d<float> > &trainingFeatures)
-{
+CostFactorySVM::CostFactorySVM()
+    : CostFactory(2,0), m_svm_type("C_SVC"), m_kernel_type("radial"), m_kernel_degree(3), m_gamma(1.0), m_coef0(0), m_ccost(1000), m_nu(0.5),  m_epsilon_loss(100), m_cache(100), m_epsilon_tol(0.001), m_shrinking(false), m_prob_est(true){
+}
+
+CostFactorySVM::~CostFactorySVM(){
+}
+
+CostFactorySVM::CostFactorySVM(std::string svm_type, std::string kernel_type, unsigned short kernel_degree, float gamma, float coef0, float ccost, float nu,  float epsilon_loss, int cache, float epsilon_tol, bool shrinking, bool prob_est, unsigned short cv, bool verbose)
+    : CostFactory(cv,verbose), m_svm_type(svm_type), m_kernel_type(kernel_type), m_kernel_degree(kernel_degree), m_gamma(gamma), m_coef0(coef0), m_ccost(ccost), m_nu(nu),  m_epsilon_loss(epsilon_loss), m_cache(cache), m_epsilon_tol(epsilon_tol), m_shrinking(shrinking), m_prob_est(prob_est){};
+
+double CostFactorySVM::getCost(const vector<Vector2d<float> > &trainingFeatures){
   std::map<std::string, svm::SVM_TYPE> svmMap;
 
   svmMap["C_SVC"]=svm::C_SVC;
@@ -88,32 +75,32 @@ double getCost(const vector<Vector2d<float> > &trainingFeatures)
   unsigned int ntraining=0;
   unsigned int ntest=0;
   for(int iclass=0;iclass<nclass;++iclass){
-    ntraining+=nctraining[iclass];
-    ntest+=nctest[iclass];
+    ntraining+=m_nctraining[iclass];
+    ntest+=m_nctest[iclass];
   }
   if(ntest)
-    assert(!cv_opt[0]);
-  if(!cv_opt[0])
+    assert(!m_cv);
+  if(!m_cv)
     assert(ntest);
   unsigned short nFeatures=trainingFeatures[0][0].size();
 
   struct svm_parameter param;
-  param.svm_type = svmMap[svm_type_opt[0]];
-  param.kernel_type = kernelMap[kernel_type_opt[0]];
-  param.degree = kernel_degree_opt[0];
-  param.gamma = (gamma_opt[0]>0)? gamma_opt[0] : 1.0/nFeatures;
-  param.coef0 = coef0_opt[0];
-  param.nu = nu_opt[0];
-  param.cache_size = cache_opt[0];
-  param.C = ccost_opt[0];
-  param.eps = epsilon_tol_opt[0];
-  param.p = epsilon_loss_opt[0];
-  param.shrinking = (shrinking_opt[0])? 1 : 0;
-  param.probability = (prob_est_opt[0])? 1 : 0;
+  param.svm_type = svmMap[m_svm_type];
+  param.kernel_type = kernelMap[m_kernel_type];
+  param.degree = m_kernel_degree;
+  param.gamma = (m_gamma>0)? m_gamma : 1.0/nFeatures;
+  param.coef0 = m_coef0;
+  param.nu = m_nu;
+  param.cache_size = m_cache;
+  param.C = m_ccost;
+  param.eps = m_epsilon_tol;
+  param.p = m_epsilon_loss;
+  param.shrinking = (m_shrinking)? 1 : 0;
+  param.probability = (m_prob_est)? 1 : 0;
   param.nr_weight = 0;//not used: I use priors and balancing
   param.weight_label = NULL;
   param.weight = NULL;
-  param.verbose=(verbose_opt[0]>1)? true:false;
+  param.verbose=(m_verbose>1)? true:false;
   struct svm_model* svm;
   struct svm_problem prob;
   struct svm_node* x_space;
@@ -126,7 +113,7 @@ double getCost(const vector<Vector2d<float> > &trainingFeatures)
   int lIndex=0;
   for(int iclass=0;iclass<nclass;++iclass){
     // for(int isample=0;isample<trainingFeatures[iclass].size();++isample){
-    for(int isample=0;isample<nctraining[iclass];++isample){
+    for(int isample=0;isample<m_nctraining[iclass];++isample){
       prob.x[lIndex]=&(x_space[spaceIndex]);
       for(int ifeature=0;ifeature<nFeatures;++ifeature){
         x_space[spaceIndex].index=ifeature+1;
@@ -140,26 +127,27 @@ double getCost(const vector<Vector2d<float> > &trainingFeatures)
   }
 
   assert(lIndex==prob.l);
-  if(verbose_opt[0]>2)
+  if(m_verbose>2)
     std::cout << "checking parameters" << std::endl;
   svm_check_parameter(&prob,&param);
-  if(verbose_opt[0]>2)
+  if(m_verbose>2)
     std::cout << "parameters ok, training" << std::endl;
   svm=svm_train(&prob,&param);
-  if(verbose_opt[0]>2)
+  if(m_verbose>2)
     std::cout << "SVM is now trained" << std::endl;
 
-  if(cv_opt[0]>1){
+  m_cm.clearResults();
+  if(m_cv>1){
     double *target = Malloc(double,prob.l);
-    svm_cross_validation(&prob,&param,cv_opt[0],target);
+    svm_cross_validation(&prob,&param,m_cv,target);
     assert(param.svm_type != EPSILON_SVR&&param.svm_type != NU_SVR);//only for regression
     for(int i=0;i<prob.l;i++){
-      string refClassName=nameVector[prob.y[i]];
-      string className=nameVector[target[i]];
-      if(classValueMap.size())
-	cm.incrementResult(type2string<short>(classValueMap[refClassName]),type2string<short>(classValueMap[className]),1.0);
+      string refClassName=m_nameVector[prob.y[i]];
+      string className=m_nameVector[target[i]];
+      if(m_classValueMap.size())
+	m_cm.incrementResult(type2string<short>(m_classValueMap[refClassName]),type2string<short>(m_classValueMap[className]),1.0);
       else
-	cm.incrementResult(cm.getClass(prob.y[i]),cm.getClass(target[i]),1.0);
+	m_cm.incrementResult(m_cm.getClass(prob.y[i]),m_cm.getClass(target[i]),1.0);
     }
     free(target);
   }
@@ -168,35 +156,36 @@ double getCost(const vector<Vector2d<float> > &trainingFeatures)
     vector<double> result(nclass);
     x_test = Malloc(struct svm_node,(nFeatures+1));
     for(int iclass=0;iclass<nclass;++iclass){
-      for(int isample=0;isample<nctest[iclass];++isample){
+      for(int isample=0;isample<m_nctest[iclass];++isample){
 	for(int ifeature=0;ifeature<nFeatures;++ifeature){
 	  x_test[ifeature].index=ifeature+1;
-	  x_test[ifeature].value=trainingFeatures[iclass][nctraining[iclass]+isample][ifeature];
+	  x_test[ifeature].value=trainingFeatures[iclass][m_nctraining[iclass]+isample][ifeature];
 	}
 	x_test[nFeatures].index=-1;
 	double predict_label=0;
-	//todo: make distinction between svm_predict and svm_predict_probability?
 	assert(svm_check_probability_model(svm));
 	predict_label = svm_predict_probability(svm,x_test,&(result[0]));
-	string refClassName=nameVector[iclass];
-	string className=nameVector[static_cast<short>(predict_label)];
-	if(classValueMap.size())
-	  cm.incrementResult(type2string<short>(classValueMap[refClassName]),type2string<short>(classValueMap[className]),1.0);
+	// predict_label = svm_predict(svm,x_test);
+	string refClassName=m_nameVector[iclass];
+	string className=m_nameVector[static_cast<short>(predict_label)];
+	if(m_classValueMap.size())
+	  m_cm.incrementResult(type2string<short>(m_classValueMap[refClassName]),type2string<short>(m_classValueMap[className]),1.0);
 	else
-	  cm.incrementResult(refClassName,className,1.0);
+	  m_cm.incrementResult(refClassName,className,1.0);
       }
     }
     free(x_test);
   }
-  if(verbose_opt[0]>1)
-    std::cout << cm << std::endl;
-  assert(cm.nReference());
-  // if(verbose_opt[0])
-  //   std::cout << cm << std::endl;
-  // std::cout << "Kappa: " << cm.kappa() << std::endl;
+  if(m_verbose>1)
+    std::cout << m_cm << std::endl;
+  assert(m_cm.nReference());
+  // if(m_verbose)
+
+  // std::cout << m_cm << std::endl;
+  // std::cout << "Kappa: " << m_cm.kappa() << std::endl;
   // double se95_oa=0;
   // double doa=0;
-  // doa=cm.oa_pct(&se95_oa);
+  // doa=m_cm.oa_pct(&se95_oa);
   // std::cout << "Overall Accuracy: " << doa << " (" << se95_oa << ")"  << std::endl;
 
   // *NOTE* Because svm_model contains pointers to svm_problem, you can
@@ -208,7 +197,7 @@ double getCost(const vector<Vector2d<float> > &trainingFeatures)
   free(x_space);
   svm_free_and_destroy_model(&(svm));
 
-  return(cm.kappa());
+  return(m_cm.kappa());
 }
 
 int main(int argc, char *argv[])
@@ -232,6 +221,23 @@ int main(int argc, char *argv[])
   Optionpk<string> selector_opt("sm", "sm", "feature selection method (sffs=sequential floating forward search,sfs=sequential forward search, sbs, sequential backward search ,bfs=brute force search)","sffs"); 
   Optionpk<float> epsilon_cost_opt("ecost", "ecost", "epsilon for stopping criterion in cost function to determine optimal number of features",0.001);
 
+  Optionpk<std::string> svm_type_opt("svmt", "svmtype", "type of SVM (C_SVC, nu_SVC,one_class, epsilon_SVR, nu_SVR)","C_SVC");
+  Optionpk<std::string> kernel_type_opt("kt", "kerneltype", "type of kernel function (linear,polynomial,radial,sigmoid) ","radial");
+  Optionpk<unsigned short> kernel_degree_opt("kd", "kd", "degree in kernel function",3);
+  Optionpk<float> gamma_opt("g", "gamma", "gamma in kernel function",1.0);
+  Optionpk<float> coef0_opt("c0", "coef0", "coef0 in kernel function",0);
+  Optionpk<float> ccost_opt("cc", "ccost", "the parameter C of C-SVC, epsilon-SVR, and nu-SVR",1000);
+  Optionpk<float> nu_opt("nu", "nu", "the parameter nu of nu-SVC, one-class SVM, and nu-SVR",0.5);
+  Optionpk<float> epsilon_loss_opt("eloss", "eloss", "the epsilon in loss function of epsilon-SVR",0.1);
+  Optionpk<int> cache_opt("cache", "cache", "cache memory size in MB",100);
+  Optionpk<float> epsilon_tol_opt("etol", "etol", "the tolerance of termination criterion",0.001);
+  Optionpk<bool> shrinking_opt("shrink", "shrink", "whether to use the shrinking heuristics",false);
+  Optionpk<bool> prob_est_opt("pe", "probest", "whether to train a SVC or SVR model for probability estimates",true,2);
+  Optionpk<unsigned short> cv_opt("cv", "cv", "n-fold cross validation mode",2);
+  Optionpk<string> classname_opt("c", "class", "list of class names."); 
+  Optionpk<short> classvalue_opt("r", "reclass", "list of class values (use same order as in classname opt."); 
+  Optionpk<short> verbose_opt("v", "verbose", "set to: 0 (results only), 1 (confusion matrix), 2 (debug)",0);
+
   bool doProcess;//stop process when program was invoked with help option (-h --help)
   try{
     doProcess=input_opt.retrieveOption(argc,argv);
@@ -260,9 +266,9 @@ int main(int argc, char *argv[])
     epsilon_tol_opt.retrieveOption(argc,argv);
     shrinking_opt.retrieveOption(argc,argv);
     prob_est_opt.retrieveOption(argc,argv);
-    cv_opt.retrieveOption(argc,argv);
     selector_opt.retrieveOption(argc,argv);
     epsilon_cost_opt.retrieveOption(argc,argv);
+    cv_opt.retrieveOption(argc,argv);
     classname_opt.retrieveOption(argc,argv);
     classvalue_opt.retrieveOption(argc,argv);
     verbose_opt.retrieveOption(argc,argv);
@@ -276,10 +282,11 @@ int main(int argc, char *argv[])
     exit(0);//help was invoked, stop processing
   }
 
+  CostFactorySVM costfactory(svm_type_opt[0], kernel_type_opt[0], kernel_degree_opt[0], gamma_opt[0], coef0_opt[0], ccost_opt[0], nu_opt[0],  epsilon_loss_opt[0], cache_opt[0], epsilon_tol_opt[0], shrinking_opt[0], prob_est_opt[0], cv_opt[0], verbose_opt[0]);
+
   assert(training_opt.size());
   if(input_opt.size())
-    cv_opt[0]=0;
-
+    costfactory.setCv(0);
   if(verbose_opt[0]>=1){
     if(input_opt.size())
       std::cout << "input filename: " << input_opt[0] << std::endl;
@@ -319,13 +326,10 @@ int main(int argc, char *argv[])
   if(band_opt.size())
     std::sort(band_opt.begin(),band_opt.end());
 
-  // map<string,short> classValueMap;//global variable for now (due to getCost)
-  // vector<std::string> nameVector;//global variable for now (due to getCost)
-
   if(classname_opt.size()){
     assert(classname_opt.size()==classvalue_opt.size());
     for(int iclass=0;iclass<classname_opt.size();++iclass)
-      classValueMap[classname_opt[iclass]]=classvalue_opt[iclass];
+      costfactory.setClassValueMap(classname_opt[iclass],classvalue_opt[iclass]);
   }
 
   //----------------------------------- Training -------------------------------
@@ -339,8 +343,8 @@ int main(int argc, char *argv[])
 
   struct svm_problem prob;
   //organize training data
-  // trainingPixels.clear();
-  // testPixels.clear();
+  trainingPixels.clear();
+  testPixels.clear();
   if(verbose_opt[0]>=1)
     std::cout << "reading training file " << training_opt[0] << std::endl;
   try{
@@ -400,6 +404,7 @@ int main(int argc, char *argv[])
       trainingMap.erase(mapit);
       continue;
     }
+    costfactory.pushBackName(mapit->first);
     trainingPixels.push_back(mapit->second);
     if(verbose_opt[0]>1)
       std::cout << mapit->first << ": " << (mapit->second).size() << " samples" << std::endl;
@@ -412,6 +417,17 @@ int main(int argc, char *argv[])
 
   mapit=testMap.begin();
   while(mapit!=testMap.end()){
+    if(costfactory.getClassValueMap().size()){
+    // if(classValueMap.size()){
+      //check if name in test is covered by classname_opt (values can not be 0)
+      if((costfactory.getClassValueMap())[mapit->first]>0){
+    	;//ok, no need to print to std::cout 
+      }
+      else{
+    	std::cerr << "Error: names in classname option are not complete, please check names in test vector and make sure classvalue is > 0" << std::endl;
+    	exit(1);
+      }
+    }    
     //no need to delete small classes for test sample
     testPixels.push_back(mapit->second);
     if(verbose_opt[0]>1)
@@ -500,45 +516,21 @@ int main(int argc, char *argv[])
     // std::cout << std::endl;
   }
 
+  //set names in confusion matrix using nameVector
+  vector<string> nameVector=costfactory.getNameVector();
+  for(int iname=0;iname<nameVector.size();++iname){
+    if(costfactory.getClassValueMap().empty())
+      costfactory.pushBackClassName(nameVector[iname]);
+      // cm.pushBackClassName(nameVector[iname]);
+    else if(costfactory.getClassIndex(type2string<short>((costfactory.getClassValueMap())[nameVector[iname]]))<0)
+      costfactory.pushBackClassName(type2string<short>((costfactory.getClassValueMap())[nameVector[iname]]));
+  }
 
-  //new
-  // map<string,Vector2d<float> >::iterator mapit=trainingMap.begin();
-  mapit=trainingMap.begin();
-  bool doSort=true;
-  try{
-    while(mapit!=trainingMap.end()){
-      nameVector.push_back(mapit->first);
-      if(classValueMap.size()){
-	//check if name in training is covered by classname_opt (values can not be 0)
-	if(classValueMap[mapit->first]>0){
-	  if(cm.getClassIndex(type2string<short>(classValueMap[mapit->first]))<0){
-	    cm.pushBackClassName(type2string<short>(classValueMap[mapit->first]),doSort);
-	  }
-	}
-	else{
-	  std::cerr << "Error: names in classname option are not complete, please check names in training vector and make sure classvalue is > 0" << std::endl;
-	  exit(1);
-	}
-      }
-      else
-	cm.pushBackClassName(mapit->first,doSort);
-      ++mapit;
-    }
-  }
-  catch(BadConversion conversionString){
-    std::cerr << "Error: did you provide class pairs names (-c) and integer values (-r) for each class in training vector?" << std::endl;
-    exit(1);
-  }
-  if(classname_opt.empty()){
-    //std::cerr << "Warning: no class name and value pair provided for all " << nclass << " classes, using string2type<int> instead!" << std::endl;
-    for(int iclass=0;iclass<nclass;++iclass){
-      if(verbose_opt[0])
-	std::cout << iclass << " " << cm.getClass(iclass) << " -> " << string2type<short>(cm.getClass(iclass)) << std::endl;
-      classValueMap[cm.getClass(iclass)]=string2type<short>(cm.getClass(iclass));
-    }
-  }
 
   //Calculate features of training (and test) set
+
+  vector<unsigned int> nctraining;
+  vector<unsigned int> nctest;
   nctraining.resize(nclass);
   nctest.resize(nclass);
   vector< Vector2d<float> > trainingFeatures(nclass);
@@ -583,7 +575,9 @@ int main(int argc, char *argv[])
     }
     assert(trainingFeatures[iclass].size()==nctraining[iclass]+nctest[iclass]);
   }
-    
+
+  costfactory.setNcTraining(nctraining);
+  costfactory.setNcTest(nctest);
   int nFeatures=trainingFeatures[0][0].size();
   int maxFeatures=(maxFeatures_opt[0])? maxFeatures_opt[0] : 1;
   double previousCost=-1;
@@ -591,36 +585,36 @@ int main(int argc, char *argv[])
   list<int> subset;//set of selected features (levels) for each class combination
   FeatureSelector selector;
   try{
-    if(maxFeatures==nFeatures){
+    if(maxFeatures>=nFeatures){
       subset.clear();
       for(int ifeature=0;ifeature<nFeatures;++ifeature)
         subset.push_back(ifeature);
-      cost=getCost(trainingFeatures);
+      cost=costfactory.getCost(trainingFeatures);
     }
     else{
-      while(fabs(cost-previousCost)>epsilon_cost_opt[0]){
+      while(fabs(cost-previousCost)>=epsilon_cost_opt[0]){
         previousCost=cost;
         switch(selMap[selector_opt[0]]){
         case(SFFS):
           subset.clear();//needed to clear in case of floating and brute force search
-          cost=selector.floating(trainingFeatures,&getCost,subset,maxFeatures,verbose_opt[0]);
+          cost=selector.floating(trainingFeatures,costfactory,subset,maxFeatures,epsilon_cost_opt[0],verbose_opt[0]);
           break;
         case(SFS):
-          cost=selector.forward(trainingFeatures,&getCost,subset,maxFeatures,verbose_opt[0]);
+          cost=selector.forward(trainingFeatures,costfactory,subset,maxFeatures,verbose_opt[0]);
           break;
         case(SBS):
-          cost=selector.backward(trainingFeatures,&getCost,subset,maxFeatures,verbose_opt[0]);
+          cost=selector.backward(trainingFeatures,costfactory,subset,maxFeatures,verbose_opt[0]);
           break;
         case(BFS):
           subset.clear();//needed to clear in case of floating and brute force search
-          cost=selector.bruteForce(trainingFeatures,&getCost,subset,maxFeatures,verbose_opt[0]);
+          cost=selector.bruteForce(trainingFeatures,costfactory,subset,maxFeatures,verbose_opt[0]);
           break;
         default:
           std::cout << "Error: selector not supported, please use sffs, sfs, sbs or bfs" << std::endl;
           exit(1);
           break;
         }
-        if(verbose_opt[0]){
+        if(verbose_opt[0]>1){
           std::cout << "cost: " << cost << std::endl;
           std::cout << "previousCost: " << previousCost << std::endl;
           std::cout << std::setprecision(12) << "cost-previousCost: " << cost - previousCost << " ( " << epsilon_cost_opt[0] << ")" << std::endl;
@@ -639,6 +633,7 @@ int main(int argc, char *argv[])
 
   if(verbose_opt[0])
     cout <<"cost: " << cost << endl;
+  subset.sort();
   for(list<int>::const_iterator lit=subset.begin();lit!=subset.end();++lit)
     std::cout << " -b " << *lit;
   std::cout << std::endl;
